__all__ = [
    'AggregatedSolutionSearchResult',
    'AssignmentSearchResult',
    'AttachmentSearchResult',
    'MessageThreadSearchResult',
    'ProjectSearchResult',
    'PoolSearchResult',
    'SkillSearchResult',
    'TaskSearchResult',
    'TaskSuiteSearchResult',
    'TrainingSearchResult',
    'UserBonusSearchResult',
    'UserRestrictionSearchResult',
    'UserSkillSearchResult',
    'WebhookSubscriptionSearchResult',
    'OperationSearchResult',
    'AppProjectSearchResult',
    'AppSearchResult',
    'AppItemSearchResult',
    'AppBatchSearchResult',
]
import toloka.client.aggregation
import toloka.client.app
import toloka.client.assignment
import toloka.client.attachment
import toloka.client.message_thread
import toloka.client.operations
import toloka.client.pool
import toloka.client.primitives.base
import toloka.client.project
import toloka.client.skill
import toloka.client.task
import toloka.client.task_suite
import toloka.client.training
import toloka.client.user_bonus
import toloka.client.user_restriction
import toloka.client.user_skill
import toloka.client.webhook_subscription
import typing


class AggregatedSolutionSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found AggregatedSolutions and whether there is something else on the original request

    Attributes:
        items: List of found AggregatedSolution
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.aggregation.AggregatedSolution]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AggregatedSolutionSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.aggregation.AggregatedSolution]]
    has_more: typing.Optional[bool]


class AssignmentSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found assignments.

    The number of assignments in the list is limited by the [find_assignments](toloka.client.TolokaClient.find_assignments.md) method.

    Attributes:
        items: The list of found assignments.
        has_more: More items flag:
            * `True` — Not all assignments matching search criteria are returned in the `items` due to the limit.
            * `False` — All matching assignments are in the `items`.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.assignment.Assignment]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AssignmentSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.assignment.Assignment]]
    has_more: typing.Optional[bool]


class AttachmentSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found attachments and whether there is something else on the original request

    It's better to use TolokaClient.get_attachments(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found Attachment
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.attachment.Attachment]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AttachmentSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.attachment.Attachment]]
    has_more: typing.Optional[bool]


class MessageThreadSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found message chains and whether there is something else on the original request

    It's better to use TolokaClient.get_message_threads(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found MessageThread
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.message_thread.MessageThread]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class MessageThreadSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.message_thread.MessageThread]]
    has_more: typing.Optional[bool]


class ProjectSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found projects and whether there is something else on the original request

    It's better to use TolokaClient.get_projects(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found projects
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.project.Project]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class ProjectSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.project.Project]]
    has_more: typing.Optional[bool]


class PoolSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found pools and whether there is something else on the original request

    It's better to use TolokaClient.get_pools(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found pools
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.pool.Pool]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class PoolSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.pool.Pool]]
    has_more: typing.Optional[bool]


class SkillSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found skills and whether there is something else on the original request

    It's better to use TolokaClient.get_skill(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found skills
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.skill.Skill]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class SkillSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.skill.Skill]]
    has_more: typing.Optional[bool]


class TaskSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found tasks and whether there is something else on the original request

    It's better to use TolokaClient.get_tasks(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found tasks
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.task.Task]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class TaskSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.task.Task]]
    has_more: typing.Optional[bool]


class TaskSuiteSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found sets of tasks and whether there is something else on the original request

    It's better to use TolokaClient.get_task_suites(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found sets of tasks
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.task_suite.TaskSuite]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class TaskSuiteSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.task_suite.TaskSuite]]
    has_more: typing.Optional[bool]


class TrainingSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found training pools and whether there is something else on the original request

    It's better to use TolokaClient.get_trainings(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found training pools
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.training.Training]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class TrainingSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.training.Training]]
    has_more: typing.Optional[bool]


class UserBonusSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found `UserBonus` instances and whether there is something else on the original request

    It's better to use TolokaClient.get_user_bonuses(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found `UserBonus` instances
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.user_bonus.UserBonus]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class UserBonusSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.user_bonus.UserBonus]]
    has_more: typing.Optional[bool]


class UserRestrictionSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found Toloker restrictions and whether there is something else on the original request

    It's better to use TolokaClient.get_user_restrictions(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found Toloker restrictions
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.user_restriction.UserRestriction]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class UserRestrictionSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.user_restriction.UserRestriction]]
    has_more: typing.Optional[bool]


class UserSkillSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found Toloker skills and whether there is something else on the original request

    It's better to use TolokaClient.get_user_skills(), which already implements the correct handling of the search result.

    Attributes:
        items: List of found Toloker skills
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.user_skill.UserSkill]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class UserSkillSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.user_skill.UserSkill]]
    has_more: typing.Optional[bool]


class WebhookSubscriptionSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found subscriptions and whether there is something else on the original request

    It's better to use TolokaClient.get_webhook_subscriptions(),
    which already implements the correct handling of the search result.

    Attributes:
        items: List of found subscriptions
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.webhook_subscription.WebhookSubscription]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class WebhookSubscriptionSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.webhook_subscription.WebhookSubscription]]
    has_more: typing.Optional[bool]


class OperationSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The list of found operations and whether there is something else on the original request

    It's better to use TolokaClient.get_operations(),
    which already implements the correct handling of the search result.

    Attributes:
        items: List of found operations
        has_more: Whether the list is complete:
            * True - Not all elements are included in the output due to restrictions in the limit parameter.
            * False - The output lists all the items.
    """

    def __init__(
        self,
        *,
        items: typing.Optional[typing.List[toloka.client.operations.Operation]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class OperationSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    items: typing.Optional[typing.List[toloka.client.operations.Operation]]
    has_more: typing.Optional[bool]


class AppProjectSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The result of searching App projects.

    Attributes:
        content: A list with found App projects.
        has_more: A flag showing whether there are more matching projects.
            * True — There are more matching projects, not included in `content` due to the limit set in the search request.
            * False — `content` contains all matching projects.
    """

    def __init__(
        self,
        *,
        content: typing.Optional[typing.List[toloka.client.app.AppProject]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AppProjectSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    content: typing.Optional[typing.List[toloka.client.app.AppProject]]
    has_more: typing.Optional[bool]


class AppSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The result of searching App projects.

    Attributes:
        content: A list with found App solutions.
        has_more: A flag showing whether there are more matching solutions.
            * True — There are more matching solutions, not included in `content` due to the limit set in the search request.
            * False — `content` contains all matching solutions.
    """

    def __init__(
        self,
        *,
        content: typing.Optional[typing.List[toloka.client.app.App]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AppSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    content: typing.Optional[typing.List[toloka.client.app.App]]
    has_more: typing.Optional[bool]


class AppItemSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The result of searching App task items.

    Attributes:
        content: A list with found App task items.
        has_more: A flag showing whether there are more matching task items.
            * True — There are more matching task items, not included in `content` due to the limit set in the search request.
            * False — `content` contains all matching task items.
    """

    def __init__(
        self,
        *,
        content: typing.Optional[typing.List[toloka.client.app.AppItem]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AppItemSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    content: typing.Optional[typing.List[toloka.client.app.AppItem]]
    has_more: typing.Optional[bool]


class AppBatchSearchResult(toloka.client.primitives.base.BaseTolokaObject):
    """The result of searching batches in an App project.

    Attributes:
        content: A list with found App batches.
        has_more: A flag showing whether there are more matching batches.
            * True — There are more matching batches, not included in `content` due to the limit set in the search request.
            * False — `content` contains all matching batches.
    """

    def __init__(
        self,
        *,
        content: typing.Optional[typing.List[toloka.client.app.AppBatch]] = None,
        has_more: typing.Optional[bool] = None
    ) -> None:
        """Method generated by attrs for class AppBatchSearchResult.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    content: typing.Optional[typing.List[toloka.client.app.AppBatch]]
    has_more: typing.Optional[bool]
